@@ -184,7 +184,8 @@ func StatusCheckRollupGraphQLWithoutCountByState(after string) string {
 								context,
 								state,
 								targetUrl,
-								createdAt
+								createdAt,
+								description
 							},
 							...on CheckRun {
 								name,
@@ -222,11 +223,12 @@ func RequiredStatusCheckRollupGraphQL(prID, after string) string {
 								state,
 								targetUrl,
 								createdAt,
+								description,
 								isRequired(pullRequestId: %[2]s)
 							},
 							...on CheckRun {
 								name,
-								checkSuite{workflowRun{workflow{name}}},
+								checkSuite{workflowRun{event,workflow{name}}},
 								status,
 								conclusion,
 								startedAt,
