@@ -1,6 +1,7 @@
 package download
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"io"
@@ -139,17 +140,19 @@ func downloadRun(opts *DownloadOptions) error {
 		return err
 	}
 
-	opts.IO.StartProgressIndicator()
+	opts.IO.StartProgressIndicatorWithLabel("Finding assets to download")
 	defer opts.IO.StopProgressIndicator()
 
+	ctx := context.Background()
+
 	var release *shared.Release
 	if opts.TagName == "" {
-		release, err = shared.FetchLatestRelease(httpClient, baseRepo)
+		release, err = shared.FetchLatestRelease(ctx, httpClient, baseRepo)
 		if err != nil {
 			return err
 		}
 	} else {
-		release, err = shared.FetchRelease(httpClient, baseRepo, opts.TagName)
+		release, err = shared.FetchRelease(ctx, httpClient, baseRepo, opts.TagName)
 		if err != nil {
 			return err
 		}
@@ -193,7 +196,7 @@ func downloadRun(opts *DownloadOptions) error {
 		stdout:       opts.IO.Out,
 	}
 
-	return downloadAssets(&dest, httpClient, toDownload, opts.Concurrency, isArchive)
+	return downloadAssets(&dest, httpClient, toDownload, opts.Concurrency, isArchive, opts.IO)
 }
 
 func matchAny(patterns []string, name string) bool {
@@ -205,7 +208,7 @@ func matchAny(patterns []string, name string) bool {
 	return false
 }
 
-func downloadAssets(dest *destinationWriter, httpClient *http.Client, toDownload []shared.ReleaseAsset, numWorkers int, isArchive bool) error {
+func downloadAssets(dest *destinationWriter, httpClient *http.Client, toDownload []shared.ReleaseAsset, numWorkers int, isArchive bool, io *iostreams.IOStreams) error {
 	if numWorkers == 0 {
 		return errors.New("the number of concurrent workers needs to be greater than 0")
 	}
@@ -220,6 +223,7 @@ func downloadAssets(dest *destinationWriter, httpClient *http.Client, toDownload
 	for w := 1; w <= numWorkers; w++ {
 		go func() {
 			for a := range jobs {
+				io.StartProgressIndicatorWithLabel(fmt.Sprintf("Downloading %s", a.Name))
 				results <- downloadAsset(dest, httpClient, a.APIURL, a.Name, isArchive)
 			}
 		}()
@@ -237,6 +241,8 @@ func downloadAssets(dest *destinationWriter, httpClient *http.Client, toDownload
 		}
 	}
 
+	io.StopProgressIndicator()
+
 	return downloadError
 }
 
@@ -353,29 +359,34 @@ func (w destinationWriter) check(fp string) error {
 	return nil
 }
 
-// Copy writes the data from r into a file specified by name
-func (w destinationWriter) Copy(name string, r io.Reader) error {
+// Copy writes the data from r into a file specified by name.
+func (w destinationWriter) Copy(name string, r io.Reader) (copyErr error) {
 	fp := w.makePath(name)
 	if fp == "-" {
-		_, err := io.Copy(w.stdout, r)
-		return err
+		_, copyErr = io.Copy(w.stdout, r)
+		return
 	}
-	if err := w.check(fp); err != nil {
-		return err
+	if copyErr = w.check(fp); copyErr != nil {
+		return
 	}
 
 	if dir := filepath.Dir(fp); dir != "." {
-		if err := os.MkdirAll(dir, 0755); err != nil {
-			return err
+		if copyErr = os.MkdirAll(dir, 0755); copyErr != nil {
+			return
 		}
 	}
 
-	f, err := os.OpenFile(fp, os.O_WRONLY|os.O_CREATE, 0644)
-	if err != nil {
-		return err
+	var f *os.File
+	if f, copyErr = os.OpenFile(fp, os.O_WRONLY|os.O_CREATE|os.O_TRUNC, 0644); copyErr != nil {
+		return
 	}
-	defer f.Close()
 
-	_, err = io.Copy(f, r)
-	return err
+	defer func() {
+		if err := f.Close(); copyErr == nil && err != nil {
+			copyErr = err
+		}
+	}()
+
+	_, copyErr = io.Copy(f, r)
+	return
 }
